diff --git a/indra/newview/llcallfloater.cpp b/indra/newview/llcallfloater.cpp
index 97a5c3b8e22d14bdd5863f67688af99dcf41273d..0aaaa8e70533cac0d3adcb2e9181346f44ce650a 100644
--- a/indra/newview/llcallfloater.cpp
+++ b/indra/newview/llcallfloater.cpp
@@ -303,8 +303,8 @@ void LLCallFloater::updateSession()
 	refreshParticipantList();
 	updateAgentModeratorState();
 
-	//show floater for voice calls
-	if (!is_local_chat)
+	//show floater for voice calls & only in CONNECTED to voice channel state
+	if (!is_local_chat && LLVoiceChannel::STATE_CONNECTED == voice_channel->getState())
 	{
 		LLIMFloater* im_floater = LLIMFloater::findInstance(session_id);
 		bool show_me = !(im_floater && im_floater->getVisible());